.. _zero:

zero
====

.. currentmodule:: zero

.. automodule:: zero

.. rubric:: Data and Tensors

.. autosummary::
   :nosignatures:
   :toctree: api
   :template: class.rst

   Stream

.. autosummary::
   :nosignatures:
   :toctree: api

   collate
   concat
   iter_batches

.. rubric:: Utilities

.. autosummary::
   :nosignatures:
   :toctree: api
   :template: class.rst

   ProgressTracker
   Timer

.. autosummary::
   :nosignatures:
   :toctree: api
   :template: class_simple.rst

   evaluation

.. rubric:: Submodules

See the sidebar on the left.
